==> com.liferay.object.service-1.0.149-sources-commercial.jar: com/liferay/object/internal/field/business/type/LargeFileObjectFieldBusinessType.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.field.business.type;

import com.liferay.object.constants.ObjectFieldConstants;
import com.liferay.object.field.business.type.ObjectFieldBusinessType;
import com.liferay.portal.kernel.language.Language;
import com.liferay.portal.vulcan.extension.PropertyDefinition;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcela Cunha
 */
@Component(
	property = "object.field.business.type.key=" + ObjectFieldConstants.BUSINESS_TYPE_LARGE_FILE,
	service = ObjectFieldBusinessType.class
)
public class LargeFileObjectFieldBusinessType
	implements ObjectFieldBusinessType {

	@Override
	public String getDBType() {
		return ObjectFieldConstants.DB_TYPE_BLOB;
	}

	@Override
	public String getDDMFormFieldTypeName() {
		return null;
	}

	@Override
	public String getLabel(Locale locale) {
		return _language.get(locale, "large-file");
	}

	@Override
	public String getName() {
		return ObjectFieldConstants.BUSINESS_TYPE_LARGE_FILE;
	}

	@Override
	public PropertyDefinition.PropertyType getPropertyType() {
		return PropertyDefinition.PropertyType.TEXT;
	}

	@Override
	public boolean isVisible() {
		return false;
	}

	@Reference
	private Language _language;

}

==> com.liferay.object.service-1.0.153-sources-commercial.jar: com/liferay/object/internal/field/business/type/LargeFileObjectFieldBusinessType.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.field.business.type;

import com.liferay.object.constants.ObjectFieldConstants;
import com.liferay.object.field.business.type.ObjectFieldBusinessType;
import com.liferay.object.model.ObjectDefinition;
import com.liferay.portal.kernel.language.Language;
import com.liferay.portal.vulcan.extension.PropertyDefinition;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcela Cunha
 */
@Component(
	property = "object.field.business.type.key=" + ObjectFieldConstants.BUSINESS_TYPE_LARGE_FILE,
	service = ObjectFieldBusinessType.class
)
public class LargeFileObjectFieldBusinessType
	implements ObjectFieldBusinessType {

	@Override
	public String getDBType() {
		return ObjectFieldConstants.DB_TYPE_BLOB;
	}

	@Override
	public String getDDMFormFieldTypeName() {
		return null;
	}

	@Override
	public String getLabel(Locale locale) {
		return _language.get(locale, "large-file");
	}

	@Override
	public String getName() {
		return ObjectFieldConstants.BUSINESS_TYPE_LARGE_FILE;
	}

	@Override
	public PropertyDefinition.PropertyType getPropertyType() {
		return PropertyDefinition.PropertyType.TEXT;
	}

	@Override
	public boolean isVisible(ObjectDefinition objectDefinition) {
		return false;
	}

	@Reference
	private Language _language;

}
